@@ -1,3 +1,4 @@
+import datetime
 from unittest import TestCase
 
 from jetbrains_issues_dataset.idea.idea_activity_manager import IdeaActivityManager
@@ -12,6 +13,7 @@ class TestIssueCreatedSnapshotStrategy(TestCase):
 
         issue = list(snapshot_strategy.issues.values())[0]
         self.assertEqual(issue['fixed_by'], 'assignee_developer')
+        self.assertEqual(issue['fixed_at'], datetime.datetime(2020, 10, 6, 21, 45, 26))
 
     def test_all_main_field_presence(self):
         snapshot_strategy = IssueCreatedSnapshotStrategy()
@@ -22,6 +24,7 @@ class TestIssueCreatedSnapshotStrategy(TestCase):
         self.assertTrue('summary' in issue)
         self.assertTrue('description' in issue)
         self.assertTrue('state' in issue)
+        self.assertTrue('reporter' in issue)
 
     def test_read_all(self):
         snapshot_strategy = IssueCreatedSnapshotStrategy()
